"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import UnrecognizedStr
from typing import Literal, Union


TypesIntegrationEntityType = Union[
    Literal[
        "customer",
        "plan",
        "invoice",
        "subscription",
        "payment",
        "credit_note",
        "addon",
        "item",
        "item_price",
        "price",
    ],
    UnrecognizedStr,
]
