"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_address import DtoAddress, DtoAddressTypedDict
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoTenantBillingDetailsTypedDict(TypedDict):
    address: NotRequired[DtoAddressTypedDict]
    email: NotRequired[str]
    help_email: NotRequired[str]
    phone: NotRequired[str]


class DtoTenantBillingDetails(BaseModel):
    address: Optional[DtoAddress] = None

    email: Optional[str] = None

    help_email: Optional[str] = None

    phone: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["address", "email", "help_email", "phone"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
