"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .types_entitytype import TypesEntityType
from .types_filetype import TypesFileType
from .types_tasktype import TypesTaskType
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class DtoCreateTaskRequestTypedDict(TypedDict):
    entity_type: TypesEntityType
    file_type: TypesFileType
    file_url: str
    task_type: TypesTaskType
    file_name: NotRequired[str]
    metadata: NotRequired[Dict[str, Any]]


class DtoCreateTaskRequest(BaseModel):
    entity_type: TypesEntityType

    file_type: TypesFileType

    file_url: str

    task_type: TypesTaskType

    file_name: Optional[str] = None

    metadata: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["file_name", "metadata"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
