"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_usageresult import DtoUsageResult, DtoUsageResultTypedDict
from .types_aggregationtype import TypesAggregationType
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoGetUsageResponseTypedDict(TypedDict):
    event_name: NotRequired[str]
    results: NotRequired[List[DtoUsageResultTypedDict]]
    type: NotRequired[TypesAggregationType]
    value: NotRequired[float]


class DtoGetUsageResponse(BaseModel):
    event_name: Optional[str] = None

    results: Optional[List[DtoUsageResult]] = None

    type: Optional[TypesAggregationType] = None

    value: Optional[float] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["event_name", "results", "type", "value"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
