"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_billingperiodinfo import DtoBillingPeriodInfo, DtoBillingPeriodInfoTypedDict
from .dto_featureusagesummary import (
    DtoFeatureUsageSummary,
    DtoFeatureUsageSummaryTypedDict,
)
from .types_paginationresponse import (
    TypesPaginationResponse,
    TypesPaginationResponseTypedDict,
)
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoCustomerUsageSummaryResponseTypedDict(TypedDict):
    customer_id: NotRequired[str]
    features: NotRequired[List[DtoFeatureUsageSummaryTypedDict]]
    pagination: NotRequired[TypesPaginationResponseTypedDict]
    period: NotRequired[DtoBillingPeriodInfoTypedDict]


class DtoCustomerUsageSummaryResponse(BaseModel):
    customer_id: Optional[str] = None

    features: Optional[List[DtoFeatureUsageSummary]] = None

    pagination: Optional[TypesPaginationResponse] = None

    period: Optional[DtoBillingPeriodInfo] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["customer_id", "features", "pagination", "period"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
