"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_deletepricerequest import (
    DtoDeletePriceRequest,
    DtoDeletePriceRequestTypedDict,
)
from flexprice_py.types import BaseModel
from flexprice_py.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class DeletePriceRequestTypedDict(TypedDict):
    id: str
    r"""Price ID"""
    body: DtoDeletePriceRequestTypedDict
    r"""Delete Price Request"""


class DeletePriceRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Price ID"""

    body: Annotated[
        DtoDeletePriceRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""Delete Price Request"""
