"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_matchedsubscriptionlineitem import (
    DtoMatchedSubscriptionLineItem,
    DtoMatchedSubscriptionLineItemTypedDict,
)
from .errors_errorresponse import ErrorsErrorResponse, ErrorsErrorResponseTypedDict
from .types_debugtrackerstatus import TypesDebugTrackerStatus
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoSubscriptionLineItemLookupResultTypedDict(TypedDict):
    error: NotRequired[ErrorsErrorResponseTypedDict]
    matched_line_items: NotRequired[List[DtoMatchedSubscriptionLineItemTypedDict]]
    status: NotRequired[TypesDebugTrackerStatus]


class DtoSubscriptionLineItemLookupResult(BaseModel):
    error: Optional[ErrorsErrorResponse] = None

    matched_line_items: Optional[List[DtoMatchedSubscriptionLineItem]] = None

    status: Optional[TypesDebugTrackerStatus] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["error", "matched_line_items", "status"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
