"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .types_alertthreshold import TypesAlertThreshold, TypesAlertThresholdTypedDict
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TypesAlertSettingsTypedDict(TypedDict):
    alert_enabled: NotRequired[bool]
    critical: NotRequired[TypesAlertThresholdTypedDict]
    info: NotRequired[TypesAlertThresholdTypedDict]
    warning: NotRequired[TypesAlertThresholdTypedDict]


class TypesAlertSettings(BaseModel):
    alert_enabled: Optional[bool] = None

    critical: Optional[TypesAlertThreshold] = None

    info: Optional[TypesAlertThreshold] = None

    warning: Optional[TypesAlertThreshold] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["alert_enabled", "critical", "info", "warning"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
