"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_updatetaskstatusrequest import (
    DtoUpdateTaskStatusRequest,
    DtoUpdateTaskStatusRequestTypedDict,
)
from flexprice_py.types import BaseModel
from flexprice_py.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateTaskStatusRequestTypedDict(TypedDict):
    id: str
    r"""Task ID"""
    body: DtoUpdateTaskStatusRequestTypedDict
    r"""Status update"""


class UpdateTaskStatusRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Task ID"""

    body: Annotated[
        DtoUpdateTaskStatusRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""Status update"""
